@@ -177,7 +177,8 @@ def cli():
         if db_dir.startswith('http://') or db_dir.startswith(
                 'https://') or db_dir.startswith('tcp://') or Path(
                     db_dir).is_socket() or db_dir.endswith(
-                        '.sock') or db_dir.endswith('.socket'):
+                        '.sock') or db_dir.endswith(
+                            '.socket') or db_dir.startswith('elbus://'):
             options['timeout'] = 60
             # TODO variable timeout
             remote = True
